@@ -14,7 +14,8 @@ class ExternalDocumentation(BaseModel):
 
     url: AnyUrl
     """
-    **REQUIRED**. The URL for the target documentation. Value MUST be in the format of a URL.
+    **REQUIRED**. The URL for the target documentation.
+    Value MUST be in the form of a URL.
     """
 
     class Config:
